==> kubernetes-model-core-4.13.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/PodTemplateListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class PodTemplateListFluentImpl<A extends PodTemplateListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PodTemplateListFluent<A> {

    private String apiVersion;
    private List<PodTemplateBuilder> items =  new ArrayList<PodTemplateBuilder>();
    private String kind;
    private ListMetaBuilder metadata;

    public PodTemplateListFluentImpl() { 
    }


    public PodTemplateListFluentImpl(PodTemplateList instance) { 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }


    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,PodTemplate item) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,PodTemplate item) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        PodTemplateBuilder builder = new PodTemplateBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(PodTemplate... items) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<PodTemplate> items) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(PodTemplate... items) {
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<PodTemplate> items) {
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<PodTemplateBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<PodTemplateBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          PodTemplateBuilder builder = each.next();
          if (predicate.apply(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodTemplate> getItems() {
        return build(items);
    }

    public List<PodTemplate> buildItems() {
        return build(items);
    }

    public PodTemplate buildItem(int index) {
        return this.items.get(index).build();
    }

    public PodTemplate buildFirstItem() {
        return this.items.get(0).build();
    }

    public PodTemplate buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public PodTemplate buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodTemplateBuilder> predicate) {
        for (PodTemplateBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodTemplateBuilder> predicate) {
        for (PodTemplateBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<PodTemplate> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<PodTemplateBuilder>(); for (PodTemplate item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(PodTemplate... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (PodTemplate item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public PodTemplateListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public PodTemplateListFluent.ItemsNested<A> addNewItemLike(PodTemplate item) {
        return new ItemsNestedImpl(-1, item);
    }

    public PodTemplateListFluent.ItemsNested<A> setNewItemLike(int index,PodTemplate item) {
        return new ItemsNestedImpl(index, item);
    }

    public PodTemplateListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public PodTemplateListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public PodTemplateListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public PodTemplateListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodTemplateBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.apply(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public PodTemplateListFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public PodTemplateListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item) {
        return new MetadataNestedImpl(item);
    }

    public PodTemplateListFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public PodTemplateListFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public PodTemplateListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PodTemplateListFluentImpl that = (PodTemplateListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends PodTemplateFluentImpl<PodTemplateListFluent.ItemsNested<N>> implements PodTemplateListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final PodTemplateBuilder builder;
        private final int index;

        ItemsNestedImpl(int index,PodTemplate item) {
            this.index = index;
            this.builder = new PodTemplateBuilder(this, item);
        }

        ItemsNestedImpl() {
            this.index = -1;
            this.builder = new PodTemplateBuilder(this);
        }

        public N and() {
             return (N) PodTemplateListFluentImpl.this.setToItems(index,builder.build());
        }

        public N endItem() {
             return and();
        }
    }


    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<PodTemplateListFluent.MetadataNested<N>> implements PodTemplateListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ListMetaBuilder builder;

        MetadataNestedImpl(ListMeta item) {
            this.builder = new ListMetaBuilder(this, item);
        }

        MetadataNestedImpl() {
            this.builder = new ListMetaBuilder(this);
        }

        public N and() {
             return (N) PodTemplateListFluentImpl.this.withMetadata(builder.build());
        }

        public N endMetadata() {
             return and();
        }
    }


}

==> kubernetes-model-core-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/PodTemplateListFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class PodTemplateListFluentImpl<A extends PodTemplateListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements PodTemplateListFluent<A> {

    private String apiVersion;
    private List<PodTemplateBuilder> items =  new ArrayList<PodTemplateBuilder>();
    private String kind;
    private ListMetaBuilder metadata;

    public PodTemplateListFluentImpl() { 
    }


    public PodTemplateListFluentImpl(PodTemplateList instance) { 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }


    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,PodTemplate item) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,PodTemplate item) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        PodTemplateBuilder builder = new PodTemplateBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(PodTemplate... items) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<PodTemplate> items) {
        if (this.items == null) {this.items = new ArrayList<PodTemplateBuilder>();}
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(PodTemplate... items) {
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<PodTemplate> items) {
        for (PodTemplate item : items) {PodTemplateBuilder builder = new PodTemplateBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<PodTemplateBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<PodTemplateBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          PodTemplateBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodTemplate> getItems() {
        return build(items);
    }

    public List<PodTemplate> buildItems() {
        return build(items);
    }

    public PodTemplate buildItem(int index) {
        return this.items.get(index).build();
    }

    public PodTemplate buildFirstItem() {
        return this.items.get(0).build();
    }

    public PodTemplate buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public PodTemplate buildMatchingItem(Predicate<PodTemplateBuilder> predicate) {
        for (PodTemplateBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<PodTemplateBuilder> predicate) {
        for (PodTemplateBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<PodTemplate> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<PodTemplateBuilder>(); for (PodTemplate item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(PodTemplate... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (PodTemplate item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public PodTemplateListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public PodTemplateListFluent.ItemsNested<A> addNewItemLike(PodTemplate item) {
        return new ItemsNestedImpl(-1, item);
    }

    public PodTemplateListFluent.ItemsNested<A> setNewItemLike(int index,PodTemplate item) {
        return new ItemsNestedImpl(index, item);
    }

    public PodTemplateListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public PodTemplateListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public PodTemplateListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public PodTemplateListFluent.ItemsNested<A> editMatchingItem(Predicate<PodTemplateBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public PodTemplateListFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public PodTemplateListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item) {
        return new MetadataNestedImpl(item);
    }

    public PodTemplateListFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public PodTemplateListFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public PodTemplateListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PodTemplateListFluentImpl that = (PodTemplateListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends PodTemplateFluentImpl<PodTemplateListFluent.ItemsNested<N>> implements PodTemplateListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final PodTemplateBuilder builder;
        private final int index;

        ItemsNestedImpl(int index,PodTemplate item) {
            this.index = index;
            this.builder = new PodTemplateBuilder(this, item);
        }

        ItemsNestedImpl() {
            this.index = -1;
            this.builder = new PodTemplateBuilder(this);
        }

        public N and() {
             return (N) PodTemplateListFluentImpl.this.setToItems(index,builder.build());
        }

        public N endItem() {
             return and();
        }
    }


    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<PodTemplateListFluent.MetadataNested<N>> implements PodTemplateListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ListMetaBuilder builder;

        MetadataNestedImpl(ListMeta item) {
            this.builder = new ListMetaBuilder(this, item);
        }

        MetadataNestedImpl() {
            this.builder = new ListMetaBuilder(this);
        }

        public N and() {
             return (N) PodTemplateListFluentImpl.this.withMetadata(builder.build());
        }

        public N endMetadata() {
             return and();
        }
    }


}
